==> openGion6.4.1.0_src.zip: gf/src/org/opengion/fukurou/process/AbstractProcess.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.process;

import org.opengion.fukurou.util.Argument;
import org.opengion.fukurou.util.HybsConst;				// 6.1.0.0 (2014/12/26) refactoring

import java.util.Map;

/**
 * AbstractProcess は、ChainProcess インターフェースを実装した、Abstract クラスです。
 * ChainProcess を用いて、順次、バッチプロセスを実行することができます。
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public abstract class AbstractProcess implements HybsProcess {

	/** システムの改行コードを設定します。*/
	protected static final String CR		 = HybsConst.CR;			// 6.1.0.0 (2014/12/26) refactoring
	/** StringBilderなどの初期値を設定します。	{@value} */
	protected static final int BUFFER_MIDDLE = HybsConst.BUFFER_MIDDLE;	// 6.1.0.0 (2014/12/26) refactoring
	/** StringBilderなどの初期値を設定します。	{@value} */
	protected static final int BUFFER_LARGE  = HybsConst.BUFFER_LARGE;	// 6.1.0.0 (2014/12/26) refactoring

	/** タブセパレータ  */
	public static final char TAB = '\t';	// 6.0.2.5 (2014/10/31) タブ区切り文字を char 化します。

	private final Argument argments ;
	private LoggerProcess logger	;

	/**
	 * コンストラクター
	 *
	 * @param	name			このクラス(サブクラス)のクラス名称
	 * @param   mustProparty	必須チェックMap
	 * @param   usableProparty	整合性チェックMap
	 */
	public AbstractProcess( final String name , final Map<String,String> mustProparty ,final Map<String,String> usableProparty ) {
		argments = new Argument( name ) ;
		argments.setMustProparty( mustProparty );
		argments.setUsableProparty( usableProparty );
	}

	/**
	 * 引数形式を解析する 引数オブジェクトに、引数を設定します。
	 * Argument の文字列から、引数かプロパティをセットします。
	 * ［プロパティ］のキー部の大文字･小文字は、厳格に判定しています。
	 * Argument の文字列には、タイプがあります。
	 *
	 * ［コメント］  ： # で始まる引数で、使用されません。(登録もされません。)
	 * ［引数］      ： #,-,= 以外で始まる通常の文字列。登録の順番が指定されます。
	 * ［プロパティ］： - で始まり、キーと値を=で区切っているパラメータです。順序は無関係。
	 *
	 * @param   arg	引数
	 */
	public void putArgument( final String arg ) {
		argments.putArgument( arg ) ;
	}

	/**
	 * Argument の文字列から、プロパティをセットします。
	 * ［プロパティ］のキー部の大文字･小文字は、厳格に判定しています。
	 * このメソッドは、引数 や コメントの判断を行いません。プロパティ のみ
	 * 設定されるものとして、処理します。
	 * プロパティの key=val が初めから分割されている場合の簡易メソッドです。
	 *
	 * @param   key キー
	 * @param   val 値
	 */
	public void putArgument( final String key,final String val ) {
		argments.putArgument( key,val ) ;
	}

	/**
	 * 引数形式を解析する 引数オブジェクトを返します。
	 *
	 * @return	引数オブジェクト
	 */
	public Argument getArgument() {
		return argments ;
	}

	/**
	 * ディスプレイにメッセージを表示します。
	 *
	 * @param	msg	表示するメッセージ
	 */
	public void println( final String msg ) {
		if( logger != null ) {
			logger.println( msg ) ;
		}
	}

	/**
	 * ディスプレイにメッセージを表示します。
	 *
	 * @param	msg	表示するメッセージ
	 */
	public void logging( final String msg ) {
		if( logger != null ) {
			logger.logging( msg ) ;
		}
	}

	/**
	 * ディスプレイ出力する LoggerProcess オブジェクトをセットします。
	 *
	 * @param logger LoggerProcessオブジェクト
	 */
	public final void setLoggerProcess( final LoggerProcess logger ) {
		this.logger = logger ;
	}

	/**
	 * エラー発生時に、RuntimeException を throw するか、ログ出力します。
	 * 引数に、エラーメッセージを指定します。
	 * isAbend引数は、RuntimeException を throw するか、ログ出力するかを指定する
	 * 引数です。true で、RuntimeException を throw し、false で、ログ出力
	 * のみとします。（つまり、継続処理されます。）
	 *
	 * @og.rev 6.3.1.1 (2015/07/10) RuntimeException を throwする機能を追加
	 *
	 * @param	errMsg	エラーメッセージ
	 * @param	isAbend	異常発生時に、処理を中断(true)するか、継続(false)するか
	 */
	public void throwException( final String errMsg , final boolean isAbend ) {
		throwException( errMsg,null,isAbend );
	}

	/**
	 * エラー発生時に、RuntimeException を throw するか、ログ出力します。
	 * 引数に、エラーメッセージと、発生元 Throwable を指定します。
	 * 発生元 Throwable が null の場合は、エラーメッセージのみで throw します。
	 * isAbend引数は、RuntimeException を throw するか、ログ出力するかを指定する
	 * 引数です。true で、RuntimeException を throw し、false で、ログ出力
	 * のみとします。（つまり、継続処理されます。）
	 *
	 * @og.rev 6.3.1.1 (2015/07/10) RuntimeException を throwする機能を追加
	 *
	 * @param	errMsg	エラーメッセージ
	 * @param	th		発生元 Throwable
	 * @param	isAbend	異常発生時に、処理を中断(true)するか、継続(false)するか
	 */
	public void throwException( final String errMsg,final Throwable th,final boolean isAbend ) {
		if( isAbend ) {
			throw th == null ? new RuntimeException( errMsg ) : new RuntimeException( errMsg,th );
		}
		else {
			logging( "=================================================================" );
			if( errMsg != null ) { logging( errMsg ); }
			if( th     != null ) { logging( th.getMessage() ); }
		}
	}

	/**
	 * プロセスの内容表示を行います。
	 * Argument#toString() を呼び出しています。
	 *
	 * @return 内容表示
	 */
	@Override
	public String toString() {
		return argments.toString();
	}
}

==> openGion6.7.6.0_src.zip: gf/src/org/opengion/fukurou/process/AbstractProcess.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.process;

import org.opengion.fukurou.util.Argument;
import org.opengion.fukurou.system.HybsConst;				// 6.1.0.0 (2014/12/26) refactoring

import java.util.Map;

/**
 * AbstractProcess は、ChainProcess インターフェースを実装した、Abstract クラスです。
 * ChainProcess を用いて、順次、バッチプロセスを実行することができます。
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public abstract class AbstractProcess implements HybsProcess {

	/** システムの改行コードを設定します。*/
	protected static final String CR		 = HybsConst.CR;			// 6.1.0.0 (2014/12/26) refactoring
	/** StringBilderなどの初期値を設定します。	{@value} */
	protected static final int BUFFER_MIDDLE = HybsConst.BUFFER_MIDDLE;	// 6.1.0.0 (2014/12/26) refactoring
	/** StringBilderなどの初期値を設定します。	{@value} */
	protected static final int BUFFER_LARGE  = HybsConst.BUFFER_LARGE;	// 6.1.0.0 (2014/12/26) refactoring

	/** タブセパレータ  */
	public static final char TAB = '\t';	// 6.0.2.5 (2014/10/31) タブ区切り文字を char 化します。

	private final Argument argments ;
	private LoggerProcess logger	;

	/**
	 * コンストラクター
	 *
	 * @param	name			このクラス(サブクラス)のクラス名称
	 * @param   MUST_PROPARTY	必須チェックMap
	 * @param   USABLE_PROPARTY	整合性チェックMap
	 */
	public AbstractProcess( final String name , final Map<String,String> MUST_PROPARTY ,final Map<String,String> USABLE_PROPARTY ) {
		argments = new Argument( name ) ;
		argments.setMustProparty( MUST_PROPARTY );
		argments.setUsableProparty( USABLE_PROPARTY );
	}

	/**
	 * 引数形式を解析する 引数オブジェクトに、引数を設定します。
	 * Argument の文字列から、引数かプロパティをセットします。
	 * ［プロパティ］のキー部の大文字･小文字は、厳格に判定しています。
	 * Argument の文字列には、タイプがあります。
	 *
	 * ［コメント］  ： # で始まる引数で、使用されません。(登録もされません。)
	 * ［引数］      ： #,-,= 以外で始まる通常の文字列。登録の順番が指定されます。
	 * ［プロパティ］： - で始まり、キーと値を=で区切っているパラメータです。順序は無関係。
	 *
	 * @param   arg	引数
	 */
	public void putArgument( final String arg ) {
		argments.putArgument( arg ) ;
	}

	/**
	 * Argument の文字列から、プロパティをセットします。
	 * ［プロパティ］のキー部の大文字･小文字は、厳格に判定しています。
	 * このメソッドは、引数 や コメントの判断を行いません。プロパティ のみ
	 * 設定されるものとして、処理します。
	 * プロパティの key=val が初めから分割されている場合の簡易メソッドです。
	 *
	 * @param   key キー
	 * @param   val 値
	 */
	public void putArgument( final String key,final String val ) {
		argments.putArgument( key,val ) ;
	}

	/**
	 * 引数形式を解析する 引数オブジェクトを返します。
	 *
	 * @return	引数オブジェクト
	 */
	public Argument getArgument() {
		return argments ;
	}

	/**
	 * ディスプレイにメッセージを表示します。
	 *
	 * @param	msg	表示するメッセージ
	 */
	public void println( final String msg ) {
		if( logger != null ) {
			logger.println( msg ) ;
		}
	}

	/**
	 * ディスプレイにメッセージを表示します。
	 *
	 * @param	msg	表示するメッセージ
	 */
	public void logging( final String msg ) {
		if( logger != null ) {
			logger.logging( msg ) ;
		}
	}

	/**
	 * ディスプレイ出力する LoggerProcess オブジェクトをセットします。
	 *
	 * @param logger LoggerProcessオブジェクト
	 */
	public final void setLoggerProcess( final LoggerProcess logger ) {
		this.logger = logger ;
	}

	/**
	 * エラー発生時に、RuntimeException を throw するか、ログ出力します。
	 * 引数に、エラーメッセージを指定します。
	 * isAbend引数は、RuntimeException を throw するか、ログ出力するかを指定する
	 * 引数です。true で、RuntimeException を throw し、false で、ログ出力
	 * のみとします。（つまり、継続処理されます。）
	 *
	 * @og.rev 6.3.1.1 (2015/07/10) RuntimeException を throwする機能を追加
	 *
	 * @param	errMsg	エラーメッセージ
	 * @param	isAbend	異常発生時に、処理を中断(true)するか、継続(false)するか
	 */
	public void throwException( final String errMsg , final boolean isAbend ) {
		throwException( errMsg,null,isAbend );
	}

	/**
	 * エラー発生時に、RuntimeException を throw するか、ログ出力します。
	 * 引数に、エラーメッセージと、発生元 Throwable を指定します。
	 * 発生元 Throwable が null の場合は、エラーメッセージのみで throw します。
	 * isAbend引数は、RuntimeException を throw するか、ログ出力するかを指定する
	 * 引数です。true で、RuntimeException を throw し、false で、ログ出力
	 * のみとします。（つまり、継続処理されます。）
	 *
	 * @og.rev 6.3.1.1 (2015/07/10) RuntimeException を throwする機能を追加
	 *
	 * @param	errMsg	エラーメッセージ
	 * @param	th		発生元 Throwable
	 * @param	isAbend	異常発生時に、処理を中断(true)するか、継続(false)するか
	 */
	public void throwException( final String errMsg,final Throwable th,final boolean isAbend ) {
		if( isAbend ) {
			throw th == null ? new RuntimeException( errMsg ) : new RuntimeException( errMsg,th );
		}
		else {
			logging( "=================================================================" );
			if( errMsg != null ) { logging( errMsg ); }
			if( th     != null ) { logging( th.getMessage() ); }
		}
	}

	/**
	 * プロセスの内容表示を行います。
	 * Argument#toString() を呼び出しています。
	 *
	 * @return 内容表示
	 */
	@Override
	public String toString() {
		return argments.toString();
	}
}
